@@ -61,8 +61,8 @@ class IdentityService(VersionedService):
         return ['v2', 'v3']
 
     @staticmethod
-    def get_service_name():
-        return ['keystone']
+    def get_service_type():
+        return ['identity']
 
     def set_identity_v3_extensions(self):
         """Returns discovered identity v3 extensions
